## Arxiv.org Categories
Here is a list of all categories and subcategories available on ArXiv
(the [script](https://gist.github.com/Mahdisadjadi/96970b043fcd94b8e5109fe8a7dbbd5e) to generate the table):

| Category | Code |  Subcategories | Subcode |
| --- | --- | --- | --- |
| Astrophysics | `astro-ph` |
| | | Astrophysics of Galaxies | `astro-ph.GA`
| | | Cosmology and Nongalactic Astrophysics | `astro-ph.CO`
| | | Earth and Planetary Astrophysics | `astro-ph.EP`
| | | High Energy Astrophysical Phenomena | `astro-ph.HE`
| | | Instrumentation and Methods for Astrophysics | `astro-ph.IM`
| | | Solar and Stellar Astrophysics | `astro-ph.SR`
| Condensed Matter | `cond-mat` |
| | | Disordered Systems and Neural Networks | `cond-mat.dis-nn`
| | | Materials Science | `cond-mat.mtrl-sci`
| | | Mesoscale and Nanoscale Physics | `cond-mat.mes-hall`
| | | Other Condensed Matter | `cond-mat.other`
| | | Quantum Gases | `cond-mat.quant-gas`
| | | Soft Condensed Matter | `cond-mat.soft`
| | | Statistical Mechanics | `cond-mat.stat-mech`
| | | Strongly Correlated Electrons | `cond-mat.str-el`
| | | Superconductivity | `cond-mat.supr-con`
| General Relativity and Quantum Cosmology | `gr-qc` |
| High Energy Physics - Experiment | `hep-ex` |
| High Energy Physics - Lattice | `hep-lat` |
| High Energy Physics - Phenomenology | `hep-ph` |
| High Energy Physics - Theory | `hep-th` |
| Mathematical Physics | `math-ph` |
| Nonlinear Sciences | `nlin` |
| | | Adaptation and Self-Organizing Systems | `nlin.AO`
| | | Cellular Automata and Lattice Gases | `nlin.CG`
| | | Chaotic Dynamics | `nlin.CD`
| | | Exactly Solvable and Integrable Systems | `nlin.SI`
| | | Pattern Formation and Solitons | `nlin.PS`
| Nuclear Experiment | `nucl-ex` |
| Nuclear Theory | `nucl-th` |
| Physics | `physics` |
| | | Accelerator Physics | `physics.acc-ph`
| | | Applied Physics | `physics.app-ph`
| | | Atmospheric and Oceanic Physics | `physics.ao-ph`
| | | Atomic Physics | `physics.atom-ph`
| | | Atomic and Molecular Clusters | `physics.atm-clus`
| | | Biological Physics | `physics.bio-ph`
| | | Chemical Physics | `physics.chem-ph`
| | | Classical Physics | `physics.class-ph`
| | | Computational Physics | `physics.comp-ph`
| | | Data Analysis, Statistics and Probability | `physics.data-an`
| | | Fluid Dynamics | `physics.flu-dyn`
| | | General Physics | `physics.gen-ph`
| | | Geophysics | `physics.geo-ph`
| | | History and Philosophy of Physics | `physics.hist-ph`
| | | Instrumentation and Detectors | `physics.ins-det`
| | | Medical Physics | `physics.med-ph`
| | | Optics | `physics.optics`
| | | Physics Education | `physics.ed-ph`
| | | Physics and Society | `physics.soc-ph`
| | | Plasma Physics | `physics.plasm-ph`
| | | Popular Physics | `physics.pop-ph`
| | | Space Physics | `physics.space-ph`
| Quantum Physics | `quant-ph` |
| Mathematics | `math` |
| | | Algebraic Geometry | `math.AG`
| | | Algebraic Topology | `math.AT`
| | | Analysis of PDEs | `math.AP`
| | | Category Theory | `math.CT`
| | | Classical Analysis and ODEs | `math.CA`
| | | Combinatorics | `math.CO`
| | | Commutative Algebra | `math.AC`
| | | Complex Variables | `math.CV`
| | | Differential Geometry | `math.DG`
| | | Dynamical Systems | `math.DS`
| | | Functional Analysis | `math.FA`
| | | General Mathematics | `math.GM`
| | | General Topology | `math.GN`
| | | Geometric Topology | `math.GT`
| | | Group Theory | `math.GR`
| | | History and Overview | `math.HO`
| | | Information Theory | `math.IT`
| | | K-Theory and Homology | `math.KT`
| | | Logic | `math.LO`
| | | Mathematical Physics | `math.MP`
| | | Metric Geometry | `math.MG`
| | | Number Theory | `math.NT`
| | | Numerical Analysis | `math.NA`
| | | Operator Algebras | `math.OA`
| | | Optimization and Control | `math.OC`
| | | Probability | `math.PR`
| | | Quantum Algebra | `math.QA`
| | | Representation Theory | `math.RT`
| | | Rings and Algebras | `math.RA`
| | | Spectral Theory | `math.SP`
| | | Statistics Theory | `math.ST`
| | | Symplectic Geometry | `math.SG`
| Computing Research Repository | `CoRR` |
| Quantitative Biology | `q-bio` |
| | | Biomolecules | `q-bio.BM`
| | | Cell Behavior | `q-bio.CB`
| | | Genomics | `q-bio.GN`
| | | Molecular Networks | `q-bio.MN`
| | | Neurons and Cognition | `q-bio.NC`
| | | Other Quantitative Biology | `q-bio.OT`
| | | Populations and Evolution | `q-bio.PE`
| | | Quantitative Methods | `q-bio.QM`
| | | Subcellular Processes | `q-bio.SC`
| | | Tissues and Organs | `q-bio.TO`
| Quantitative Finance | `q-fin` |
| | | Computational Finance | `q-fin.CP`
| | | Economics | `q-fin.EC`
| | | General Finance | `q-fin.GN`
| | | Mathematical Finance | `q-fin.MF`
| | | Portfolio Management | `q-fin.PM`
| | | Pricing of Securities | `q-fin.PR`
| | | Risk Management | `q-fin.RM`
| | | Statistical Finance | `q-fin.ST`
| | | Trading and Market Microstructure | `q-fin.TR`
| Statistics | `stat` |
| | | Applications | `stat.AP`
| | | Computation | `stat.CO`
| | | Machine Learning | `stat.ML`
| | | Methodology | `stat.ME`
| | | Other Statistics | `stat.OT`
| | | Statistics Theory | `stat.TH`
